#!/bin/sh

NAME=xvidcap
VERSION=${VERSION:-1.1.6}
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-46.1}

CWD=`pwd`
TMP=${TMP:-/tmp}
ROOT=$TMP/package-$NAME

[ -d $TMP ] || mkdir -p $TMP

cd $TMP
tar xf $CWD/$NAME-$VERSION.tar.gz || exit $?

cd $NAME-$VERSION
chown -R root.root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var/lib || exit 1

make -j1 || exit 1

rm -rf $ROOT
mkdir -p $ROOT
make install DESTDIR=$ROOT

mkdir -p $ROOT/usr/doc/$NAME-$VERSION
cp -a AUTHORS COPYING NEWS Changelog $ROOT/usr/doc/$NAME-$VERSION

find $ROOT/usr/doc/$NAME-$VERSION/ -type f -exec chmod 644 {} \;

# strip:
( cd $ROOT
  find . -print0 | xargs -0 file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . -print0 | xargs -0 file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . -print0 | xargs -0 file | grep "ar archive" | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

gzip -9 $ROOT/usr/man/*/*
rm -f $ROOT/usr/info/dir
gzip -9 $ROOT/usr/info/*

# Writeout the description file
mkdir -p $ROOT/install
cat << EOF > $ROOT/install/slack-desc
xvidcap: Screen capture utility
xvidcap:
xvidcap: xvidcap is a tool that captures movement on a selected area
xvidcap: of the screen.  It can operate in two modes capturing a number
xvidcap: of screenshots to individual files or capturing a number of
xvidcap: screenshots but encoded as a movie file.
xvidcap:
xvidcap: Audio capture is also available.
xvidcap:
xvidcap:
xvidcap:
EOF

# Copy this build script into the package
mkdir -p $ROOT/usr/src/$NAME-$VERSION
cp $CWD/build-$NAME.sh $ROOT/usr/src/$NAME-$VERSION/

chown -R root.root $ROOT

# Build the packages
cd $ROOT
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

echo "Generating md5 checksum"
md5sum $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz > $CWD/$NAME-$VERSION-$ARCH-$BUILD.md5

echo "Generating dependencies file"
requiredbuilder -z $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz > $CWD/$NAME-$VERSION-$ARCH-$BUILD.dep

# Clean up the extra stuff:
if [ "$1" = "--cleanup" ]; then
    rm -rf $TMP/$NAME-$VERSION
    rm -rf $ROOT
fi

